@@ -1879,32 +1879,7 @@ class NvModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
         complete_value_set = self.root.to_value_set()
         complete_value_set.path = save_path
 
-        reference_parameter_by_uuid = {
-            parameter.parameter_uuid: parameter
-            for parameter in reference_value_set.model.root.children
-        }
-
-        drop_list = []
-
-        for output_parameter in complete_value_set.model.root.children:
-            reference_parameter = reference_parameter_by_uuid.get(
-                output_parameter.parameter_uuid,
-            )
-            if reference_parameter is None:
-                continue
-
-            if not output_parameter.writable:
-                drop_list.append(output_parameter)
-                continue
-
-            for meta in MetaEnum.non_value:
-                setattr(output_parameter, meta.name, None)
-
-            if reference_parameter.value == output_parameter.value:
-                drop_list.append(output_parameter)
-
-        for parameter in drop_list:
-            complete_value_set.model.root.remove_child(child=parameter)
+        complete_value_set.strip_common(reference=reference_value_set)
 
         try:
             complete_value_set.save()
@@ -1915,6 +1890,45 @@ class NvModel(epyqlib.pyqabstractitemmodel.PyQAbstractItemModel):
 
         self.activity_ended.emit(message)
 
+    @pyqtSlot()
+    def write_to_sparse_value_set_file(self, parent=None):
+        fields = attr.fields(epyqlib.pm.valuesetmodel.ValueSet)
+        filters = fields.filters.default
+
+        save_path = epyqlib.utils.qt.file_dialog(
+            caption='Sparse File',
+            filters=filters,
+            save=True,
+            parent=parent,
+        )
+
+        if save_path is None:
+            return
+
+        value_set = self.root.to_value_set()
+        value_set.path = save_path
+
+        drop_list = [
+            parameter
+            for parameter in value_set.model.root.children
+            if (
+                not parameter.writable
+                or parameter.value is None
+            )
+        ]
+
+        for parameter in drop_list:
+            value_set.model.root.remove_child(child=parameter)
+
+        try:
+            value_set.save()
+        except epyqlib.pm.valuesetmodel.SaveCancelled:
+            message = 'Save cancelled'
+        else:
+            message = 'Saved to "{}"'.format(value_set.path)
+
+        self.activity_ended.emit(message)
+
     @pyqtSlot()
     def read_from_file(self, parent=None):
         filters = [
